OC.L10N.register(
    "spreed",
    {
    "a conversation" : "会話",
    "(Duration %s)" : "(%s 期限)",
    "You attended a call with {user1}" : "{user1} との通話に参加しました",
    "_%n guest_::_%n guests_" : ["ゲスト %n 名"],
    "You attended a call with {user1} and {user2}" : "{user1} と {user2} の通話に参加しました",
    "You attended a call with {user1}, {user2} and {user3}" : "{user1}、{user2} と {user3} の通話に参加しました",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "{user1}、{user2}、 {user3} と {user4} の通話に参加しました",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "{user1}、{user2}、{user3}、{user4} と {user5} の通話に参加しました",
    "_%n other_::_%n others_" : ["他 %n 名"],
    "{actor} invited you to {call}" : "{actor} から {call} に招待されました",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "<strong>会話</strong>への招待、または<strong>着信</strong>がありました",
    "Talk" : "通話",
    "Guest" : "ゲスト",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Nextcloud Talkへようこそ!\nこの会話では、Nextcloud Talkで利用できる新機能について説明します。",
    "New in Talk 6" : "トークの6つの新機能",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft EdgeとSafariで音声通話とビデオ通話ができるようになりました。",
    "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- 1対1の会話が持続的になり、なにかアクシデントが起こってもグループが解散しないようになりました。また、参加者の1人が会話を終了しても、会話は自動的に削除されません。両方の参加者が退席した場合のみ、会話はサーバーから削除されます。",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- チャットに「@all」を付けることで、参加者全員に通知できるようになりました。",
    "- With the \"arrow-up\" key you can repost your last message" : "- ↑キーを押して、最後のメッセージを再投稿できます",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talkでコマンドを使用したり、「/help」をチャットメッセージとして送信したりできるようになりました。",
    "- With projects you can create quick links between conversations, files and other items" : "- プロジェクトを使用すると、会話、ファイル、およびその他のアイテム間のクイックリンクを作成できます",
    "There are currently no commands available." : "現在使用可能なコマンドはありません。",
    "The command does not exist" : "コマンドが存在しません",
    "Talk updates ✅" : "トーク更新 ✅",
    "{actor} created the conversation" : "{actor} が会話を作成しました",
    "You created the conversation" : "会話を作成しました",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor}が会話を%1$sから%2$sにリネームしました",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "会話を%1$sから%2$sにリネームしました",
    "{actor} started a call" : "{actor}が通話を開始しました",
    "You started a call" : "通話を開始しました",
    "{actor} joined the call" : "{actor} が通話に参加しました",
    "You joined the call" : "あなたはこの通話に参加しました",
    "{actor} left the call" : "{actor} が通話を離脱しました",
    "You left the call" : "あなたはこの通話を離脱しました",
    "{actor} unlocked the conversation" : "{actor} が会話のロックを解除しました",
    "You unlocked the conversation" : "会話のロックを解除しました",
    "{actor} locked the conversation" : "{actor} が会話をロックしました",
    "You locked the conversation" : "会話をロックしました",
    "The conversation is now open to everyone" : "全員への会話が開始されました",
    "{actor} opened the conversation to everyone" : "{actor}が全員への会話を開始しました",
    "You opened the conversation to everyone" : "全員への会話を開始しました",
    "{actor} allowed guests" : "{actor} がゲストを許可しました",
    "You allowed guests" : "あなたがゲストを許可しました",
    "{actor} disallowed guests" : "{actor}がゲストを拒否しました",
    "You disallowed guests" : "ゲストを拒否しました",
    "{actor} set a password" : "{actor} がパスワードを設定しました",
    "You set a password" : "パスワードを設定する",
    "{actor} removed the password" : "{actor} がパスワードを削除しました",
    "You removed the password" : "パスワードを削除しました",
    "{actor} added {user}" : "{actor} が {user} を追加しました",
    "You joined the conversation" : "会話に参加しました",
    "{actor} joined the conversation" : "{actor}が会話に参加しました",
    "You added {user}" : "{user}を追加しました",
    "{actor} added you" : "{actor}があなたを追加しました",
    "You left the conversation" : "会話から抜けました",
    "{actor} left the conversation" : "{actor}が会話から抜けました",
    "{actor} removed {user}" : "{actor} が {user} を削除しました。",
    "You removed {user}" : "{user}を削除しました",
    "{actor} removed you" : "{actor}があなたを削除しました",
    "{actor} promoted {user} to moderator" : "{actor} が {user} をモデレーターに昇格しました",
    "You promoted {user} to moderator" : "{user} をモデレータに昇格しました",
    "{actor} promoted you to moderator" : "{actor}があなたをモデレータに昇格させました",
    "{actor} demoted {user} from moderator" : "{actor}が{user}をモデレーターから降格させました",
    "You demoted {user} from moderator" : "{user}をモデレーターから降格させました",
    "{actor} demoted you from moderator" : "{actor}があなたをモデレーターから降格させました",
    "{actor} shared a file which is no longer available" : "{actor}は使用できなくなったファイルを共有しました",
    "You shared a file which is no longer available" : "使用できなくなったファイルを共有しました",
    "%s (guest)" : "%s(ゲスト)",
    "Call with {user1} and {user2} (Duration {duration})" : "{user1}と{user2}に電話をかける(期間 {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "{user1}と{user2}と{user3}に電話をかける(期間 {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{user1}と{user2}と{user3}と{user4}に電話をかける(期間 {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{user1}と{user2}と{user3}と{user4}と{user5}に電話をかける(期間 {duration})",
    "Talk to %s" : "%s と通話",
    "File is not shared, or shared but not with the user" : "ファイルが共有されていないか、対象ユーザーを除いて共有されています",
    "%s invited you to a conversation." : "%sから会話に招待されました ",
    "You were invited to a conversation." : "会話に招待されました",
    "Conversation invitation" : "会話への招待",
    "Click the button below to join." : "下のボタンをクリックして参加します。",
    "Join »%s«" : "»%s«に参加",
    "Password request: %s" : "パスワードのリクエスト :%s",
    "Private conversation" : "プライベート会話",
    "Deleted user (%s)" : "削除済みユーザー(%s)",
    "{user} sent you a private message" : "{user} はあなたにプライベートなメッセージを送信しました",
    "{user} sent a message in conversation {call}" : "{user}は会話{call}でメッセージを送りました",
    "A deleted user sent a message in conversation {call}" : "削除されたユーザーが会話 {call} でメッセージを送信しました",
    "A guest sent a message in conversation {call}" : "ゲストが会話 {call} でメッセージを送信しました",
    "{user} replied to your private message" : "{user} はあなたのプライベートなメッセージに返信しました",
    "{user} replied to your message in conversation {call}" : " {user} が会話{call}内のメッセージに返信しました",
    "A deleted user replied to your message in conversation {call}" : "削除されたユーザーが会話 {call} であなたのメッセージに返信しました",
    "A guest replied to your message in conversation {call}" : "ゲストが会話 {call} であなたのメッセージに返信しました",
    "{user} mentioned you in a private conversation" : "{user}がプライベートな会話であなたについて言及しました",
    "{user} mentioned you in conversation {call}" : "{user}は会話 {call} であなたについて言及しました",
    "A deleted user mentioned you in conversation {call}" : "削除されたユーザーが会話 {call} であなたについて言及しました",
    "A guest mentioned you in conversation {call}" : "ゲストが会話{call}であなたのことを話しました",
    "View chat" : "チャットを見る",
    "{user} invited you to a private conversation" : "{user}があなたをプライベートな会話に招待しました",
    "Join call" : "通話開始",
    "{user} invited you to a group conversation: {call}" : "{user}がグループ会話{call}にあなたを招待しました",
    "Answer call" : "応答",
    "{user} wants to talk with you" : "{user} からの通話要請があります",
    "Call back" : "折り返し電話",
    "You missed a call from {user}" : "{user}からの着信に応答できませんでした。",
    "A group call has started in {call}" : "{call} のグループ通話が開始されました",
    "You missed a group call in {call}" : "{user}からのグループ着信に応答できませんでした。",
    "{email} is requesting the password to access {file}" : "{email}は{file}にアクセスするためのパスワードをリクエストしています",
    "{email} tried to requested the password to access {file}" : "{email}が{file}にアクセスするためのパスワードを要求しようとしました",
    "Someone is requesting the password to access {file}" : "誰かが{file}にアクセスするためのパスワードを要求しています",
    "Someone tried to requested the password to access {file}" : "誰かが{file}にアクセスするためにパスワードを要求しようとしました。",
    "Invalid date, date format must be YYYY-MM-DD" : "日付が無効です。日付形式はYYYY-MM-DDである必要があります",
    "Conversation not found" : "会話が見つかりません",
    "Path is already shared with this room" : "パスは既にこのルームで共有されています",
    "Chat, video & audio-conferencing using WebRTC" : "WebRTCを使用したチャット、ビデオ、および音声会議",
    "None" : "なし",
    "User" : "ユーザー",
    "Everyone" : "すべてのユーザー",
    "Disabled" : "無効",
    "Moderators" : "モデレータ",
    "Users" : "ユーザー",
    "TURN server URL" : "TURN server URL",
    "Validate SSL certificate" : "SSL証明書を検証する",
    "Delete this server" : "このサーバーを削除",
    "STUN server URL" : "STUN server URL",
    "TURN server secret" : "TURNサーバーシークレット",
    "TURN server protocols" : "TURNサーバープロトコル",
    "UDP and TCP" : "UDP と TCP",
    "UDP only" : "UDP のみ",
    "TCP only" : "TCP のみ",
    "Test this server" : "このサーバーをテスト",
    "[Unknown user name]" : "[不明なユーザー名]",
    "Copy link" : "リンクをコピー",
    "Chat notifications" : "チャット通知",
    "All messages" : "全てのメッセージ",
    "@-mentions only" : "@-言及 のみ",
    "Off" : "オフ",
    "Leave conversation" : "会話を離れる",
    "Delete conversation" : "会話を削除",
    "Remove from favorites" : "お気に入りから削除",
    "Add to favorites" : "お気に入りに追加",
    "moderator" : "モデレータ",
    "Demote from moderator" : "モデレータから降格",
    "Promote to moderator" : "モデレータに昇格",
    "Remove participant" : "参加者を削除",
    "Share link" : "リンクの共有",
    "Participants" : "参加者",
    "Projects" : "プロジェクト",
    "Limit to groups" : "グループに制限する",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "最低1つグループが選択されている場合、グループにリストされたユーザーのみが会話に参加できます。",
    "Guests can still join public conversations." : "ゲストはまだ公開会話に参加できます。",
    "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Talkを使用できなくなったユーザーは、以前の会話の参加者として表示されチャットメッセージも保持されます。",
    "Limit app usage to groups." : "アプリの使用をグループに制限する",
    "Save changes" : "変更を保存",
    "Saving …" : "保存中...",
    "Saved!" : "保存完了！",
    "Commands" : "コマンド",
    "Beta" : "ベータ",
    "Name" : "名前",
    "Command" : "コマンド",
    "Script" : "スクリプト",
    "Response to" : "への反応",
    "Enabled for" : "に対して有効",
    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "コマンドはNextcloud Talkの新しいベータ版の機能です。スクリプトをNextcloudサーバー上で実行することができます。コマンドラインインターフェイスを使用して定義できます。計算スクリプトの例は、<a {attributes}>ドキュメント ↗</a>に記載されています。",
    "Moderators only" : "モデレータ専用",
    "Signaling servers" : "シグナリングサーバー",
    "Saved" : "保存しました",
    "Add a new server" : "新しいサーバーの追加",
    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "大規模なインストールをする場合は、オプションで外部のシグナリングサーバーを設定するべきです。内部のシグナリングサーバーを利用するには、空欄のままにしてください。",
    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "外部のシグナリングサーバーを使用しない4人以上の参加者にとの通話では、接続の問題が発生し、参加している端末の負荷が高くなる可能性があります。",
    "Don't warn about connectivity issues in calls with more than 4 participants" : "参加者4人以上の通話の接続の問題について警告しない",
    "Shared secret" : "共有秘密鍵",
    "STUN servers" : "STUNサーバー",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUNサーバーは、ルーターを介した参加者のパブリックIPアドレスを決定するために使用されます。",
    "TURN servers" : "TURNサーバー",
    "A TURN server is used to proxy the traffic from participants behind a firewall." : "TURNサーバーは、ファイアウォール内の参加者からのトラフィックをプロキシするために使用されます。",
    "Select a conversation to add to the project" : "プロジェクトに追加する会話を選択",
    "Select conversation" : "会話を選択",
    "Join a conversation or start a new one" : "会話に参加または開始する",
    "Say hi to your friends and colleagues!" : "友達や同僚に挨拶しましょう！",
    "Link to a conversation" : "会話へのリンク",
    "This conversation is password-protected" : "この会話はパスワードで保護されています",
    "The password is wrong. Try again." : "パスワードが違います。再入力してください",
    "Password" : "パスワード",
    "Fullscreen (f)" : "全画面 (f)",
    "Specify commands the users can use in chats" : "ユーザーがチャットで使用できるコマンドを指定します",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "大規模に使用する場合は、オプションで外部のシグナリングサーバーを設定できます。内部のシグナリングサーバーを利用するには、空欄のままにしてください。",
    "TURN server" : "TURNサーバー",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURNサーバーは参加者のファイアウォール越しの通信を中継します。",
    "%s Talk on your mobile devices" : "あなたのモバイルデバイス上の会話%s",
    "Join conversations at any time, any where, on any device." : "いつでも、どこでも、どのデバイスでも会話に参加できます。",
    "Android app" : "Android アプリ",
    "iOS app" : "iOS アプリ",
    "Signaling server URL" : "シグナリングサーバーURL",
    "Delete server" : "サーバーを削除",
    "Add new server" : "新しいサーバーを追加",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "すべてのSTUNサーバーは削除されましたが、STUNサーバーは必要なのでデフォルトサーバーが設定されました。",
    "TURN server shared secret" : "TURNサーバーの共有秘密鍵",
    "Test server" : "テストサーバー",
    "New public conversation" : "新規公開会話",
    "New group conversation" : "新規会議",
    "{name} (public)" : "{name}(パブリック)",
    "New conversation …" : "新規チャット",
    "Chat" : "チャット",
    "Exit fullscreen (f)" : "全画面終了 (f)",
    "Set your name in the chat window so other participants can identify you better." : "チャットウィンドウで自分の名前を設定して、他の参加者が自分を識別しやすくします。",
    "Copy" : "コピー",
    "Copied!" : "コピーしました",
    "Not supported!" : "未対応",
    "Press ⌘-C to copy." : "⌘-C でコピーします。",
    "Press Ctrl-C to copy." : "Ctrl-C でコピーします。",
    "Error while getting the room ID" : "ルームIDの取得中にエラーが発生しました",
    "Start a conversation" : "会話を開始する",
    "Share this file with others to discuss" : "このファイルを他のユーザーと共有してディスカッションする",
    "Share" : "共有",
    "Request password" : "パスワードを入力",
    "Error requesting the password." : "パスワードのリクエスト中にエラーが発生しました。",
    "Please enter the password for this call" : "この通話のパスワードを入力してください",
    "Password required" : "パスワードが必要です",
    "Cancel" : "キャンセル",
    "Submit" : "了解",
    "Leave call" : "通話終了",
    "Start call" : "通話を開始",
    "Change password" : "パスワード変更",
    "Set password" : "パスワード設定",
    "Go to file" : "ファイルへ移動",
    "Conversation name" : "会話の名前",
    "Rename" : "名前変更",
    "Conversation with {name}" : "{name} と会話",
    "Error occurred while setting password" : "パスワード設定中にエラーが発生しました",
    "Link copied!" : "リンクをコピーしました",
    "You" : "自分",
    "No messages yet, start the conversation!" : "まだメッセージはありません。会話を開始しましょう",
    "New message …" : "新しいメッセージ …",
    "Send" : "送信",
    "Today" : "本日",
    "Yesterday" : "昨日",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The message you are trying to send is too long" : "送信しようとしているメッセージは長すぎます",
    "Error occurred while sending message" : "メッセージ送信中にエラーが発生しました",
    "File to share" : "共有するファイル",
    "Error while sharing" : "共有でエラーが発生しました",
    "Edit" : "編集",
    "No other people in this call" : "この通話には誰もいません",
    "Waiting for {participantName} to join the call …" : "{participantName} の参加を待っています …",
    "Waiting for others to join the call …" : "参加を待っています …",
    "You can invite others in the participant tab of the sidebar" : "サイドバーの参加者タブで他のユーザーを招待できます",
    "Share this link to invite others!" : "このリンクを共有して他の人を招待します。",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "サイドバーの参加者タブかこのリンクを共有して他のユーザーを招待できます。",
    "WebRTC is not supported in your browser :-/" : "このブラウザーはWebRTCをサポートしていません",
    "Please use a different browser like Firefox or Chrome" : "別のブラウザー（Firefox または Chrome 等）を使用してください",
    "Waiting for camera and microphone permissions" : "カメラとマイクの許可待ち",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "ブラウザーでカメラとマイクへのアクセスを許可してください。",
    "This conversation has ended" : "会話は終了しました",
    "Mute audio" : "音声なし",
    "Disable video" : "映像なし",
    "Share screen" : "画面共有",
    "Share whole screen" : "全画面共有",
    "Share a single window" : "ウィンドウを共有",
    "Show your screen" : "自分の画面を表示",
    "Stop screensharing" : "画面共有を停止",
    "Unmute audio (m)" : "ミュート解除 (m)",
    "Mute audio (m)" : "ミュート (m)",
    "No audio" : "音声なし",
    "Enable video (v)" : "映像あり (v)",
    "Disable video (v)" : "映像なし (v)",
    "No Camera" : "カメラがありません",
    "Screensharing is not supported by your browser." : "あなたのブラウザーは画面共有をサポートしていません。",
    "Screensharing requires the page to be loaded through HTTPS." : "画面共有はHTTPSが必要です。",
    "Screensharing options" : "画面共有オプション",
    "Sharing your screen only works with Firefox version 52 or newer." : "画面共有はFirefox バージョン52以上のみで動作します。",
    "Screensharing extension is required to share your screen." : "画面共有を利用するには画面共有エクステンションが必要です。",
    "Please use a different browser like Firefox or Chrome to share your screen." : "画面共有を利用する場合は、別のブラウザー（Firefox または Chrome 等）を使用してください。",
    "An error occurred while starting screensharing." : "画面共有の開始中にエラーが発生しました。",
    "Enable screensharing" : "画面共有を有効にする",
    "Error while promoting user to moderator" : "ユーザーをモデレータに昇格中にエラーが発生しました",
    "Error while demoting moderator" : "モデレータの降格中にエラーが発生しました",
    "Error while removing user from room" : "ルームからユーザを削除中にエラーが発生しました",
    "Add participant …" : "参加者を追加",
    "Favorited" : "お気に入り済",
    "Always notify" : "常に通知する",
    "Notify on @-mention" : "@-mentionに通知する",
    "Never notify" : "通知しない",
    "Close" : "閉じる",
    "Show screen" : "画面を表示",
    "Enable video" : "動画を有効にする",
    "Access to microphone & camera is only possible with HTTPS" : "マイクとカメラへのアクセスはHTTPSでのみ可能です",
    "Please move your setup to HTTPS" : "HTTPSを使用して設定してください",
    "Access to microphone & camera was denied" : "マイクとカメラへのアクセスが拒否されました",
    "WebRTC is not supported in your browser" : "このブラウザーはWebRTCをサポートしていません",
    "Error while accessing microphone & camera" : "マイクとカメラのアクセス中にエラーが発生しました",
    "{participantName}'s screen" : "{participantName} の画面",
    "Guest's screen" : "ゲストの画面",
    "Your screen" : "自画面",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "<strong>招待</strong>または、<strong>着信</strong>がありました。",
    "_%n other guest_::_%n other guests_" : ["他のゲスト %n 名"],
    ", " : "、",
    "Join now" : "今すぐ参加",
    "{user} sent a message in a conversation" : "{user}が会話でメッセージを送信しました",
    "A deleted user sent a message in a conversation" : "削除されたユーザーが会話内でメッセージを送信しました",
    "A guest sent a message in a conversation" : "ゲストが会話内でメッセージを送信しました",
    "{user} mentioned you in a conversation" : "{user}が会話であなたについて言及しました",
    "A deleted user mentioned you in a conversation" : "削除されたユーザーが会話であなたについて言及しました",
    "A guest mentioned you in a conversation" : "ゲストが会話であなたについて言及しました",
    "%s invited you to a private conversation" : "%sがあなたをプライベートな会話に招待しました",
    "%s invited you to a group conversation: %s" : "%sさんがあなたをグループ会話に招待しました: %s",
    "%s invited you to a group conversation" : "%sさんがあなたをグループ会話に招待しました。",
    "{user} invited you to a group conversation" : "{user}は、グループ会話にあなたを招待しました。",
    "A group call has started" : "グループ通話が開始されました",
    "{email} requested the password to access {file}" : "{email}が{file}にアクセスするためのパスワードをリクエストしています",
    "Someone requested the password to access {file}" : "誰かが{file}にアクセスするためのパスワードを要求しました。",
    "Unnamed conversation" : "無名の会話",
    "Video & audio-conferencing using WebRTC" : "WebRTCを使用したビデオ、および音声会議",
    "This call is password-protected" : "この通話はパスワードで保護されています",
    "Signaling server" : "シグナリングサーバー",
    "Enter name for a new conversation" : "相手の名前を入力してください",
    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "外部のシグナリングサーバーを使用しない4人以上の参加者による呼び出しでは、接続の問題が発生し、参加している端末の負荷が高くなる可能性があります。",
    "Room name can not be empty" : "ルーム名を空にすることはできません",
    "Calls are disabled in this conversation." : "この会話では通話は無効になっています。",
    "You can not send messages, because the conversation is locked." : "会話がロックされているため、メッセージを送信できません。",
    "The conversation is locked." : "会話はロックされています",
    "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "ビデオを有効にする (v) -ビデオを最初に有効にすると、接続が一時的に中断されます。",
    "You need to promote a new moderator before you can leave the conversation." : "会話を終了する前に、新しいモデレータを昇格する必要があります。",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "予想以上に時間がかかっています。メディア権限はすでに付与されていますか？（または拒否されていますか？）付与されている場合、オーディオとビデオが破損しているのでブラウザを再起動してください。",
    "* Microsoft Edge and Safari can now be used to participate in audio and video calls" : "* Microsoft EdgeとSafariで音声通話とビデオ通話に参加できるようになりました",
    "* One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- 1対1の会話が持続的になり、なにかアクシデントが起こってもグループ会話に変わらないようになりました。\nまた、参加者の1人が会話を終了しても、会話は自動的に削除されません。両方の参加者が退席した場合のみ、会話はサーバーから削除されます。",
    "* You can now notify all participants by posting \"@all\" into the chat" : "* チャットに「@all」を付けることで、参加者全員に通知できるようになりました。",
    "* With the \"arrow-up\" key you can repost your last message" : "* ↑キーを押して、最後のメッセージを再投稿できます",
    "* Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "* Talkでコマンドを使用したり、「/help」をチャットメッセージとして送信したりできるようになりました。",
    "* With projects you can create quick links between conversations, files and other items" : "* プロジェクトを使用すると、会話、ファイル、およびその他のアイテム間のクイックリンクを作成できます",
    "Invalid start time format" : "開始時間がフォーマットに沿っていません",
    "Start time (optional)" : "開始時間（オプション）"
},
"nplurals=1; plural=0;");
